@@ -28,6 +28,8 @@
 #' @template section_progress_bars
 #' @template section_parallelization
 #' @template section_logging
+#' @templateVar optimizer bbotk::OptimizerGridSearch
+#' @template section_optimizer
 #'
 #' @family Tuner
 #' @seealso Package \CRANpkg{mlr3hyperband} for hyperband tuning.
@@ -50,6 +52,7 @@ TunerGridSearch = R6Class("TunerGridSearch",
         param_set = param_set,
         param_classes = c("ParamLgl", "ParamInt", "ParamDbl", "ParamFct"),
         properties = c("dependencies", "single-crit", "multi-crit"),
+        label = "Grid Search",
         man = "mlr3tuning::mlr_tuners_grid_search"
       )
     }
