@@ -16,6 +16,8 @@
 #'
 #' @template section_parallelization
 #' @template section_logging
+#' @templateVar optimizer bbotk::OptimizerRandomSearch
+#' @template section_optimizer
 #'
 #' @source
 #' `r format_bib("bergstra_2012")`
@@ -32,9 +34,9 @@ TunerRandomSearch = R6Class("TunerRandomSearch",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
-        optimizer = OptimizerRandomSearch$new()
+        optimizer = OptimizerRandomSearch$new(),
+        man = "mlr3tuning::mlr_tuners_random_search"
       )
-      private$.man = "mlr3tuning::mlr_tuners_random_search"
     }
   )
 )
